@@ -1,9 +1,9 @@
 package PAR::Packer;
-use 5.006;
+use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.008';
+our $VERSION = '1.017';
 
 =head1 NAME
 
@@ -27,7 +27,6 @@ have a C compiler.
 use Config;
 use Archive::Zip ();
 use Cwd ();
-use ExtUtils::MakeMaker ();
 use File::Basename ();
 use File::Find ();
 use File::Spec ();
@@ -50,8 +49,6 @@ use constant OPTIONS => {
     'X|exclude:s@'   => 'Exclude modules',
     'f|filter:s@'    => 'Input filters for scripts',
     'g|gui'          => 'No console window',
-    'i|icon:s'       => 'Icon file',
-    'N|info:s@'      => 'Executable header info',
     'I|lib:s@'       => 'Include directories (for perl)',
     'l|link:s@'      => 'Include additional shared libraries',
     'L|log:s'        => 'Where to log packaging process information',
@@ -191,9 +188,6 @@ sub _check_write {
         if (-e _) {
             $self->_die("Cannot write on $file: $!\n") unless -w _;
         }
-        unless (-w Cwd::cwd()) {
-            $self->_die("Cannot write in this directory: $!\n");
-        }
     }
 }
 
@@ -309,8 +303,8 @@ sub _parse_opts {
         $self->_warn("Using -e 'code' as input file, ignoring @$args\n")
           if (@$args and !$opt->{r});
 
-        my ($fh, $fake_input) =
-          File::Temp::tempfile("ppXXXXX", SUFFIX => ".pl", UNLINK => 1);
+        my ($fh, $fake_input) = File::Temp::tempfile(
+	    "ppXXXXX", SUFFIX => ".pl", TMPDIR => 1, UNLINK => 1);
 
         print $fh $opt->{e};
         close $fh;
@@ -633,7 +627,8 @@ sub get_par_file {
         # Don't need to keep it, be safe with a tempfile.
 
         $self->{pack_attrib}{lose} = 1;
-        ($cfh, $par_file) = File::Temp::tempfile("ppXXXXX", SUFFIX => ".par");
+        ($cfh, $par_file) = File::Temp::tempfile(
+	    "ppXXXXX", SUFFIX => ".par", TMPDIR => 1, UNLINK => 1);
         close $cfh;    # See comment just below
     }
     $self->{par_file} = $par_file;
@@ -814,22 +809,6 @@ sub pack_manifest_hash {
             $dep_manifest->{ $root . "lib/$pfile" } =
               [ string => $content_ref ];
         }
-        elsif (
-            File::Basename::basename($map{$pfile}) =~ /^Tk\.dll$/i and $opt->{i}
-            and eval { require Win32::Exe; 1 }
-            and eval { require Win32::Exe::IconFile; 1 }
-            and 0 # XXX - broken on larger icon files - XXX
-        ) {
-            my $tkdll = Win32::Exe->new($map{$pfile});
-            $tkdll = $tkdll->create_resource_section if !$tkdll->has_resource_section;
-            my $ico = Win32::Exe::IconFile->new($opt->{i});
-            $tkdll->set_icons(scalar $ico->icons);
-
-            $full_manifest->{ $root . "lib/$pfile" } =
-              [ string => $tkdll->dump ];
-            $dep_manifest->{ $root . "lib/$pfile" } =
-              [ string => $tkdll->dump ];
-        }
         else {
             $full_manifest->{ $root . "lib/$pfile" } =
               [ file => $map{$pfile} ];
@@ -1111,9 +1090,9 @@ sub _add_file {
                 $manifest->{ $alias } = [ file => $file ];
 
                 $oldsize += -s $file;
-                $zip->addFile($file, $alias);
-                $zip->memberNamed($alias)->desiredCompressionMethod($method);
-                $zip->memberNamed($alias)->desiredCompressionLevel($level);
+                my $member = $zip->addFile($file, $alias);
+                $member->desiredCompressionMethod($method);
+                $member->desiredCompressionLevel($level);
             }
         }
         elsif (-e $fn and -r $fn) {
@@ -1124,9 +1103,9 @@ sub _add_file {
             $self->_vprint(1, "... adding $fn as $in\n");
 
             $oldsize += -s $fn;
-            $zip->addFile($fn => $in);
-            $zip->memberNamed($in)->desiredCompressionMethod($method);
-            $zip->memberNamed($in)->desiredCompressionLevel($level);
+            my $member = $zip->addFile($fn => $in);
+            $member->desiredCompressionMethod($method);
+            $member->desiredCompressionLevel($level);
         }
     }
     else {
@@ -1138,9 +1117,10 @@ sub _add_file {
         $oldsize += length($str);
 
         $self->_vprint(1, "... adding <string> as $in");
-        $zip->addString($str => $in)->unixFileAttributes(0644);
-        $zip->memberNamed($in)->desiredCompressionMethod($method);
-        $zip->memberNamed($in)->desiredCompressionLevel($level);
+        my $member = $zip->addString($str => $in);
+        $member->unixFileAttributes(0644);
+        $member->desiredCompressionMethod($method);
+        $member->desiredCompressionLevel($level);
     }
 
     $self->{pack_attrib}{old_size} = $oldsize;
@@ -1255,31 +1235,10 @@ sub _par_to_exe {
     if ($^O ne 'MSWin32' or $opt->{p} or $opt->{P}) {
         $self->_generate_output();
     }
-    elsif (!$opt->{N} and !$opt->{i}) {
+    else {
         $self->_generate_output();
         $self->_fix_console() if $opt->{g};
     }
-    elsif (eval { require Win32::Exe; 1 }) {
-        $self->_move_parl();
-        my $exe = Win32::Exe->new($self->{parl});
-        $exe = $exe->create_resource_section if !$exe->has_resource_section;
-        $exe->update(
-            icon => $opt->{i},
-            info => $opt->{N},
-        );
-
-        $self->_append_parl();
-        $self->_generate_output();
-
-        $self->_fix_console();
-        unlink($self->{parl});
-        unlink($self->{orig_parl});
-        unlink("$self->{parl}.bak");
-        return;
-    }
-    else {
-        $self->_die("--icon and --info support needs Win32::Exe");
-    }
 }
 
 # extracts a parl (static) or parldyn (dynamic) from the appropriate data class
@@ -1299,9 +1258,8 @@ sub _extract_parl {
 
     $self->_vprint(0, "Generating a fresh 'parl'.");
     my ($fh, $filename) = File::Temp::tempfile(
-        "parlXXXXXXX",
-        SUFFIX => $Config{_exe},
-    );
+        "parlXXXXXXX", SUFFIX => $Config{_exe}, TMPDIR => 1, UNLINK => 1);
+    close $fh;
     
     my $success = $class->write_parl($filename);
     if (not $success) {
@@ -1313,34 +1271,6 @@ sub _extract_parl {
 }
 
 
-sub _fix_console {
-    my ($self) = @_;
-
-    my $opt      = $self->{options};
-    my $output   = $self->{output};
-    my $dynperl  = $self->{dynperl};
-
-    return unless $opt->{g};
-
-    $self->_vprint(1, "Fixing $output to remove its console window");
-    $self->_strip_console($output);
-
-    if ($dynperl and !$opt->{d}) {
-        # we have a static.exe that needs taking care of.
-        my $buf;
-        my $fh = $self->_open($self->{orig_parl} || $self->{parl});
-        seek $fh, -8, 2;
-        read $fh, $buf, 8;
-        die unless $buf eq "\nPAR.pm\n";
-        seek $fh, -12, 2;
-        read $fh, $buf, 4;
-        seek $fh, -12 - unpack("N", $buf) - 4, 2;
-        read $fh, $buf, 4;
-        close $fh;
-        $self->_strip_console($output, unpack("N", $buf));
-    }
-}
-
 sub _move_parl {
     my ($self) = @_;
 
@@ -1349,10 +1279,7 @@ sub _move_parl {
     my $cfh;
     my $fh = $self->_open($self->{parl});
     ($cfh, $self->{parl}) = File::Temp::tempfile(
-        "parlXXXX",
-        SUFFIX => ".exe",
-        UNLINK => 1,
-    );
+        "parlXXXX", SUFFIX => ".exe", TMPDIR => 1, UNLINK => 1);
     binmode($cfh);
 
     local $/;
@@ -1415,26 +1342,32 @@ sub _generate_output {
     system($parl, @args);
 }
 
-sub _strip_console {
-    my $self   = shift;
-    my $file   = shift;
-    my $preoff = shift || 0;
+sub _fix_console {
+    my ($self) = @_;
+
+    my $opt      = $self->{options};
+    my $output   = $self->{output};
+    my $dynperl  = $self->{dynperl};
+
+    return unless $opt->{g};
+
+    $self->_vprint(1, "Fixing $output to remove its console window");
 
     my ($record, $magic, $signature, $offset, $size);
 
-    my $exe = $self->_open('+<', $file);
+    my $exe = $self->_open('+<', $output);
     binmode $exe;
-    seek $exe, $preoff, 0;
+    seek $exe, 0, 0;
 
     # read IMAGE_DOS_HEADER structure
     read $exe, $record, 64;
     ($magic, $offset) = unpack "Sx58L", $record;
 
-    die "$file is not an MSDOS executable file.\n"
+    die "$output is not an MSDOS executable file.\n"
       unless $magic == 0x5a4d;    # "MZ"
 
     # read signature, IMAGE_FILE_HEADER and first WORD of IMAGE_OPTIONAL_HEADER
-    seek $exe, $preoff + $offset, 0;
+    seek $exe, $offset, 0;
     read $exe, $record, 4 + 20 + 2;
 
     ($signature, $size, $magic) = unpack "Lx16Sx2S", $record;
@@ -1447,7 +1380,7 @@ sub _strip_console {
       ($size == 240 && $magic == 0x20b);    # IMAGE_NT_OPTIONAL_HDR64_MAGIC
 
     # Offset 68 in the IMAGE_OPTIONAL_HEADER(32|64) is the 16 bit subsystem code
-    seek $exe, $preoff + $offset + 4 + 20 + 68, 0;
+    seek $exe, $offset + 4 + 20 + 68, 0;
     print $exe pack "S", 2;                 # IMAGE_WINDOWS
     close $exe;
 }
